==> sisu-markup-samples_1.0.6.orig.tar.gz: sisu-markup-samples-1.0.6.orig/data/sisu_markup_samples/non-free/_sisu/skin/doc/skin_gnu.rb <==
=begin
 * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
 * Author: Ralph Amissah
   * http://www.jus.uio.no/sisu
   * http://www.jus.uio.no/sisu/SiSU/download
 * Description: Free Software Foundation, Gnu sisu skin
 * License: Same as SiSU see http://www.jus.uio.no/sisu
 * Notes: Site default appearance variables set in defaults.rb
     Generic site wide modifications set here scribe_skin.rb, and this file required by other "scribes" instead of defaults.rb
=end
module SiSU_Viz
  require SiSU_lib + '/defaults'
  class Skin
    #% widget
    def widget_promo
      ['sisu_icon','sisu','sisu_search_libre','open_society','fsf','ruby']
    end
    #% home
    def home_index
    end
    def home_toc
    end
    #% path
    def path_root
      './sisu/'                                                                  # the only parameter that cannot be changed here
    end
    def path_rel
      '../'
    end
    #% url
    def url_home
      'http://www.fsf.org'
    end
    def url_site                                                                     # used in pdf header
      'http://www.fsf.org'
    end
    def url_txt                                                                      # text to go with url usually stripped url
      'www.fsf.org'
    end
    def url_home_url
      '../index.html'
    end
    # color
    def color_band1
      '"#000070"'      
    end
    #% txt
    def txt_hp
    	'Free Software Foundation'
    end
    def txt_home                                                                     # this should be the name of the site eg. Lex Mercatoria or if you prefer to see a url the url in text form copy & ...
      #"www.jus.uio.no/sisu/" 
    	'Free Software Foundation'
    end
    #% icon
    def icon_home_button
      'philosophical_gnu.png'
    end
    def icon_home_banner
      icion_home_button
    end
    #% banner
    def banner_home_button
		  %{<table border="0" summary="home button" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor="#000070"><a href="#{url_site}/">#{png_home}</a></td></tr></table>\n}
    end
    def banner_home_and_index_buttons
	    %{<table><tr><td width="20%"><table summary="home and index buttons" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor="#000070"><a href="#{url_site}/" target="_top">#{png_home}</a>#{table_close}</td><td width="60%"><center><table summary="buttons" border="1" cellpadding="3" cellspacing="0"><tr><td align="center" bgcolor="#f1e8de"><font face="arial" size="2"><a href="toc" target="_top">&nbsp;This&nbsp;text&nbsp;sub-&nbsp;<br />&nbsp;Table&nbsp;of&nbsp;Contents&nbsp;</a></font>#{table_close}</center></td><td width="20%">&nbsp;#{table_close}}
    end
    def banner_band
      %{<table summary="band" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor="#000070"><a href="#{url_site}/" target="_top">#{png_home}</a>#{table_close}}
    end
    #% credits
    def credits_splash
      %{<center><table summary="credits" align="center"bgcolor="#ffffff"><tr><td>#{widget_sisu}#{widget_wayBetter}#{widget_browsers}#{widget_pdfviewers}#{table_close}</center>}
    end
  end
  class TeX
    def header_center
	    "\\chead{\\href{#{@vz.url_site}/}{www.jus.uio.no/sisu/}}"
    end
    def home_url
	    "\\href{#{@vz.url_site}/}{www.fsf.org}"
    end
    def home
	    "\\href{#{@vz.url_site}/}{Free Software Foundation}"
    end
    def owner_chapter
      "Document owner details"
    end
  end
  class Stamp
    def stmp
  	  "\\copyright Ralph Amissah to be released under the GPL (or QT License equivalent as to be decided) \\\\\n ralph@amissah.com \\\\\n www.jus.uio.no/sisu/"
    end
  end
end

==> sisu-markup-samples_1.0.9.orig.tar.gz: sisu-markup-samples-1.0.9/data/sisu_markup_samples/non-free/_sisu/skin/doc/skin_gnu.rb <==
=begin
 * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
 * Author: Ralph Amissah
   * http://www.jus.uio.no/sisu
   * http://www.jus.uio.no/sisu/SiSU/download
 * Description: Free Software Foundation, Gnu sisu skin
 * License: Same as SiSU see http://www.jus.uio.no/sisu
 * Notes: Site default appearance variables set in defaults.rb
     Generic site wide modifications set here scribe_skin.rb, and this file required by other "scribes" instead of defaults.rb
=end
module SiSU_Viz
  require SiSU_lib + '/defaults'
  class Skin
    #% widget
    def widget_promo
      # ['sisu_icon','sisu','sisu_search_libre','open_society','fsf','ruby']
    end
    #% home
    def home_index
    end
    def home_toc
    end
    #% path
    def path_root
      './sisu/'                                                                  # the only parameter that cannot be changed here
    end
    def path_rel
      '../'
    end
    #% url
    def url_home
      'http://www.fsf.org'
    end
    def url_site                                                                     # used in pdf header
      'http://www.fsf.org'
    end
    def url_txt                                                                      # text to go with url usually stripped url
      'www.fsf.org'
    end
    def url_home_url
      '../index.html'
    end
    # color
    def color_band1
      '"#000070"'
    end
    #% txt
    def txt_hp
    	'Free Software Foundation'
    end
    def txt_home                                                                     # this should be the name of the site eg. Lex Mercatoria or if you prefer to see a url the url in text form copy & ...
      #"www.jus.uio.no/sisu/"
    	'Free Software Foundation'
    end
    #% icon
    def icon_home_button
      'philosophical_gnu.png'
    end
    def icon_home_banner
      icion_home_button
    end
    #% banner
    def banner_home_button
		  %{<table border="0" summary="home button" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor="#000070"><a href="#{url_site}/">#{png_home}</a></td></tr></table>\n}
    end
    def banner_home_and_index_buttons
	    %{<table><tr><td width="20%"><table summary="home and index buttons" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor="#000070"><a href="#{url_site}/" target="_top">#{png_home}</a>#{table_close}</td><td width="60%"><center><table summary="buttons" border="1" cellpadding="3" cellspacing="0"><tr><td align="center" bgcolor="#f1e8de"><font face="arial" size="2"><a href="toc" target="_top">&nbsp;This&nbsp;text&nbsp;sub-&nbsp;<br />&nbsp;Table&nbsp;of&nbsp;Contents&nbsp;</a></font>#{table_close}</center></td><td width="20%">&nbsp;#{table_close}}
    end
    def banner_band
      %{<table summary="band" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor="#000070"><a href="#{url_site}/" target="_top">#{png_home}</a>#{table_close}}
    end
  end
  class TeX
    def header_center
	    "\\chead{\\href{#{@vz.url_site}/}{www.jus.uio.no/sisu/}}"
    end
    def home_url
	    "\\href{#{@vz.url_site}/}{www.fsf.org}"
    end
    def home
	    "\\href{#{@vz.url_site}/}{Free Software Foundation}"
    end
    def owner_chapter
      "Document owner details"
    end
  end
end
